==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/el.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'el', {
	button: {
		title: 'Ιδιότητες Κουμπιού',
		text: 'Κείμενο (Τιμή)',
		type: 'Τύπος',
		typeBtn: 'Κουμπί',
		typeSbm: 'Υποβολή',
		typeRst: 'Επαναφορά'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Ιδιότητες Κουτιού Επιλογής',
		radioTitle: 'Ιδιότητες Κουμπιού Επιλογής',
		value: 'Τιμή',
		selected: 'Επιλεγμένο'
	},
	form: {
		title: 'Ιδιότητες Φόρμας',
		menu: 'Ιδιότητες Φόρμας',
		action: 'Ενέργεια',
		method: 'Μέθοδος',
		encoding: 'Κωδικοποίηση'
	},
	hidden: {
		title: 'Ιδιότητες Κρυφού Πεδίου',
		name: 'Όνομα',
		value: 'Τιμή'
	},
	select: {
		title: 'Ιδιότητες Πεδίου Επιλογής',
		selectInfo: 'Πληροφορίες Πεδίου Επιλογής',
		opAvail: 'Διαθέσιμες Επιλογές',
		value: 'Τιμή',
		size: 'Μέγεθος',
		lines: 'γραμμές',
		chkMulti: 'Να επιτρέπονται οι πολλαπλές επιλογές',
		opText: 'Κείμενο',
		opValue: 'Τιμή',
		btnAdd: 'Προσθήκη',
		btnModify: 'Τροποποίηση',
		btnUp: 'Πάνω',
		btnDown: 'Κάτω',
		btnSetValue: 'Θέση ως προεπιλογή',
		btnDelete: 'Διαγραφή'
	},
	textarea: {
		title: 'Ιδιότητες Περιοχής Κειμένου',
		cols: 'Στήλες',
		rows: 'Σειρές'
	},
	textfield: {
		title: 'Ιδιότητες Πεδίου Κειμένου',
		name: 'Όνομα',
		value: 'Τιμή',
		charWidth: 'Πλάτος Χαρακτήρων',
		maxChars: 'Μέγιστοι χαρακτήρες',
		type: 'Τύπος',
		typeText: 'Κείμενο',
		typePass: 'Κωδικός',
		typeEmail: 'Email',
		typeSearch: 'Αναζήτηση',
		typeTel: 'Αριθμός Τηλεφώνου',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/el.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'el', {
	button: {
		title: 'Ιδιότητες Κουμπιού',
		text: 'Κείμενο (Τιμή)',
		type: 'Τύπος',
		typeBtn: 'Κουμπί',
		typeSbm: 'Υποβολή',
		typeRst: 'Επαναφορά'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Ιδιότητες Κουτιού Επιλογής',
		radioTitle: 'Ιδιότητες Κουμπιού Επιλογής',
		value: 'Τιμή',
		selected: 'Επιλεγμένο',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Ιδιότητες Φόρμας',
		menu: 'Ιδιότητες Φόρμας',
		action: 'Ενέργεια',
		method: 'Μέθοδος',
		encoding: 'Κωδικοποίηση'
	},
	hidden: {
		title: 'Ιδιότητες Κρυφού Πεδίου',
		name: 'Όνομα',
		value: 'Τιμή'
	},
	select: {
		title: 'Ιδιότητες Πεδίου Επιλογής',
		selectInfo: 'Πληροφορίες Πεδίου Επιλογής',
		opAvail: 'Διαθέσιμες Επιλογές',
		value: 'Τιμή',
		size: 'Μέγεθος',
		lines: 'γραμμές',
		chkMulti: 'Να επιτρέπονται οι πολλαπλές επιλογές',
		required: 'Required', // MISSING
		opText: 'Κείμενο',
		opValue: 'Τιμή',
		btnAdd: 'Προσθήκη',
		btnModify: 'Τροποποίηση',
		btnUp: 'Πάνω',
		btnDown: 'Κάτω',
		btnSetValue: 'Θέση ως προεπιλογή',
		btnDelete: 'Διαγραφή'
	},
	textarea: {
		title: 'Ιδιότητες Περιοχής Κειμένου',
		cols: 'Στήλες',
		rows: 'Σειρές'
	},
	textfield: {
		title: 'Ιδιότητες Πεδίου Κειμένου',
		name: 'Όνομα',
		value: 'Τιμή',
		charWidth: 'Πλάτος Χαρακτήρων',
		maxChars: 'Μέγιστοι χαρακτήρες',
		required: 'Required', // MISSING
		type: 'Τύπος',
		typeText: 'Κείμενο',
		typePass: 'Κωδικός',
		typeEmail: 'Email',
		typeSearch: 'Αναζήτηση',
		typeTel: 'Αριθμός Τηλεφώνου',
		typeUrl: 'URL'
	}
} );
